==> haskell-gi-gtk-hs-0.3.16-99-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gi-gtk-hs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gi-gtk-hs
version:              0.3.16
visibility:           public
id:                   gi-gtk-hs-0.3.16-6DMTyHnYT6OFZNvgmbAY61
key:                  gi-gtk-hs-0.3.16-6DMTyHnYT6OFZNvgmbAY61
license:              LGPL-2.1-only
maintainer:           mail@jonasplatte.de
author:
    Jonas Platte,
    Duncan Coutts,
    Axel Simon,
    Hamish Mackenzie,
    Iñaki García Etxebarria

homepage:             https://github.com/haskell-gi/haskell-gi
synopsis:
    A wrapper for gi-gtk, adding a few more idiomatic API parts on top

description:
    A wrapper for gi-gtk, adding a few more idiomatic API parts on top

category:             Graphics
abi:                  f526c763aeb6dac560b084a62f8bff3d
exposed:              True
exposed-modules:
    Data.GI.Gtk Data.GI.Gtk.BuildFn Data.GI.Gtk.ComboBox
    Data.GI.Gtk.ModelView.CellLayout Data.GI.Gtk.ModelView.CustomStore
    Data.GI.Gtk.ModelView.ForestStore Data.GI.Gtk.ModelView.SeqStore
    Data.GI.Gtk.ModelView.TreeModel Data.GI.Gtk.ModelView.Types
    Data.GI.Gtk.Threading Data.GI.Gtk.Widget

import-dirs:          /usr/lib/ghc-9.4.8/site-local/gi-gtk-hs-0.3.16
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gi-gtk-hs-0.3.16
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gi-gtk-hs-0.3.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gi-gtk-hs
hs-libraries:         HSgi-gtk-hs-0.3.16-6DMTyHnYT6OFZNvgmbAY61
depends:
    base-4.17.2.1 base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp
    containers-0.6.7 gi-gdk-3.0.26-DDmdrqADGW225yUXMLSFzo
    gi-gdkpixbuf-2.0.32-Jk9gLfPUVfLH13LPHr3zg
    gi-glib-2.0.29-3USlM9arC84FVPyc3WX0bn
    gi-gobject-2.0.30-AHSS1Hx3Cri4QlPEXtFUxX
    gi-gtk-3.0.39-CGB0YhDVE5CFII6Euj2Ypz
    haskell-gi-base-0.26.6-8Q7bG4vZp6hk1q5uA8ktg mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-gi-gtk-hs/html/gi-gtk-hs.haddock
haddock-html:         /usr/share/doc/haskell-gi-gtk-hs/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gi-gtk-hs-0.3.16-100-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gi-gtk-hs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gi-gtk-hs
version:              0.3.16
visibility:           public
id:                   gi-gtk-hs-0.3.16-1AvQvssZ09lGiwgqZdgyrp
key:                  gi-gtk-hs-0.3.16-1AvQvssZ09lGiwgqZdgyrp
license:              LGPL-2.1-only
maintainer:           mail@jonasplatte.de
author:
    Jonas Platte,
    Duncan Coutts,
    Axel Simon,
    Hamish Mackenzie,
    Iñaki García Etxebarria

homepage:             https://github.com/haskell-gi/haskell-gi
synopsis:
    A wrapper for gi-gtk, adding a few more idiomatic API parts on top

description:
    A wrapper for gi-gtk, adding a few more idiomatic API parts on top

category:             Graphics
abi:                  7f1c1e20101aaa066e720847c879f6e6
exposed:              True
exposed-modules:
    Data.GI.Gtk Data.GI.Gtk.BuildFn Data.GI.Gtk.ComboBox
    Data.GI.Gtk.ModelView.CellLayout Data.GI.Gtk.ModelView.CustomStore
    Data.GI.Gtk.ModelView.ForestStore Data.GI.Gtk.ModelView.SeqStore
    Data.GI.Gtk.ModelView.TreeModel Data.GI.Gtk.ModelView.Types
    Data.GI.Gtk.Threading Data.GI.Gtk.Widget

import-dirs:          /usr/lib/ghc-9.4.8/site-local/gi-gtk-hs-0.3.16
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gi-gtk-hs-0.3.16
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gi-gtk-hs-0.3.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gi-gtk-hs
hs-libraries:         HSgi-gtk-hs-0.3.16-1AvQvssZ09lGiwgqZdgyrp
depends:
    base-4.17.2.1 base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp
    containers-0.6.7 gi-gdk-3.0.26-5NhHATjhS1BAiY7CEeR1j3
    gi-gdkpixbuf-2.0.32-H1QpxZTxuRWB03Zn5qEugx
    gi-glib-2.0.29-4maA5nZBdZKJt4vZW34BUN
    gi-gobject-2.0.30-Ko8kBeyWYuA8GBW3WPye3A
    gi-gtk-3.0.39-LQLSabTRB5V3brhwINRzE8
    haskell-gi-base-0.26.6-8Q7bG4vZp6hk1q5uA8ktg mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-gi-gtk-hs/html/gi-gtk-hs.haddock
haddock-html:         /usr/share/doc/haskell-gi-gtk-hs/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
